imports.searchPath.push("./src");
const Gio = imports.gi.Gio;

const Convenience = imports.convenience;

const getSettings = (schemaDir) => {
    let schemaSource;
    const GioSSS = Gio.SettingsSchemaSource;
    if (schemaDir.query_exists(null))
        schemaSource = GioSSS.new_from_directory(schemaDir.get_path(),
                                                 GioSSS.get_default(),
                                                 false);
    else
        schemaSource = GioSSS.get_default();

    let schemaObj = schemaSource.lookup(schema, true);
    if (!schemaObj) {
        throw new Error(
          'Schema ' + schema + ' could not be found for extension ' +
          extension.metadata.uuid + '. Please check your installation.'
        );
    }

    return new Gio.Settings({ settings_schema: schemaObj });
}

const _Symbols = {
  error: "\u26A0",
  refresh: "\u27f3",
  up: "\u25b2",
  down: "\u25bc",
  unchanged: " ",
};

const _Colors = {
  error: '#ff0000',
};

const _Defaults = [
  {
    api: 'bitcoinaverage',
    currency: 'USD',
    coin: 'BTC',
    attribute: 'last',
    show_change: true,
    show_base_currency: false
  }
];


let IndicatorCollection = new Lang.Class({
  Name: "IndicatorCollection",

  _init: function () {
    this._indicators = [];
    this._settings = Convenience.getSettings();

    if (this._settings.get_boolean(FIRST_RUN_KEY)) {
      this._initDefaults();
      this._settings.set_boolean(FIRST_RUN_KEY, false);
    } else {
      this._upgradeSettings();
    }

    this._settingsChangedId = this._settings.connect(
      'changed::' + INDICATORS_KEY,
      this._createIndicators.bind(this)
    );

    this._createIndicators();
  },

  _initDefaults: function () {
    this._settings.set_strv(INDICATORS_KEY, _Defaults.map(JSON.stringify));
  },

  _upgradeSettings: function () {
    const applyDefaults = (options) => {
      Object.keys(_Defaults).forEach((k) => {
        if (!(k in options)) {
          options[k] = _Defaults[k];
        }
      });
      return options;
    };
    let updated = this._settings.get_strv(INDICATORS_KEY)
      .map(JSON.parse)
      .map(applyDefaults);
    this._settings.set_strv(INDICATORS_KEY, updated.map(JSON.stringify));
  },
});
